@@ -133,6 +133,7 @@ ee_Initialize <- function(user = NULL,
 
   if (drive) {
     ee_check_packages("ee_Initialize", "googledrive")
+    # your user have enough permissions to read GD files?
     if (!quiet) {
       cat(
         "",
@@ -141,6 +142,7 @@ ee_Initialize <- function(user = NULL,
       )
     }
     drive_credentials <- ee_create_credentials_drive(user, quiet = quiet)
+    test_drive_privileges(user)
     if (!quiet) {
       cat(
         "\r",
@@ -257,18 +259,6 @@ ee_Initialize <- function(user = NULL,
   ee$ImageCollection$Dataset <- eeDataset_b$ic
   ee$Image$Dataset <- eeDataset_b$image
 
-
-  # If Extra module exist add to ee!
-  tryCatch(
-    expr = {
-      class(Extra) <- c("Extra_EE_module", class(Extra))
-      ee$Extra <- Extra
-    },
-    error = function(e) {
-      {ee$Extra <- NULL}
-    }
-  )
-
   invisible(TRUE)
 }
 
@@ -823,7 +813,6 @@ ee_check_packages <- function(fn_name, packages) {
   }
 }
 
-
 #' Dataset Creator
 #' @noRd
 ee_Dataset_creator <- function(eeDataset) {
@@ -832,3 +821,31 @@ ee_Dataset_creator <- function(eeDataset) {
   eedataset_fc <- lapply(eeDataset[["FeatureCollection"]], function(x) ee$FeatureCollection(x))
   list(image = eedataset_img, ic = eedataset_ic, fc = eedataset_fc)
 }
+
+#' Testing 403 error in GD
+#' @noRd
+test_drive_privileges <-function(user) {
+  ee_check_packages("ee_Initialize(..., drive=TRUE)", "gargle")
+  # this will break in GD API v4 ... be careful :)
+  req <- gargle::request_build(
+    path = "drive/v3/files/{fileId}",
+    method = "GET",
+    params = list(fileId = "soyunparametro", supportsAllDrives = TRUE),
+    token = googledrive::drive_token()
+  )
+  resp <- gargle::request_make(req)
+  if (resp$status_code == 403) {
+    stop(
+      "Your googledrive token does not have permission\n",
+      "to view or modify files from Google Drive.\n",
+      "Did you cross the check box when Google asked for permissions?\n",
+      "See: https://github.com/r-spatial/rgee/issues/175#issuecomment-905611278\n",
+      sprintf(
+        "Run %s to fix.",
+        crayon::bold(
+          sprintf("ee_clean_credentials('%s')", user)
+        )
+      )
+    )
+  }
+}
