@@ -459,10 +459,10 @@ ee_init_task_drive_fc <- function(x_fc, dsn, container, table_id,
   if (is.na(ee_user$drive_cre)) {
     drive_credential <- ee_create_credentials_drive(ee_user$email)
     ee_save_credential(pdrive = drive_credential)
-    # ee_Initialize(email = ee_user$email, drive = TRUE)
+    # ee_Initialize(user = ee_user$email, drive = TRUE)
     message(
       "\nNOTE: Google Drive credentials were not loaded.",
-      " Running ee_Initialize(email = '",ee_user$email,"', drive = TRUE)",
+      " Running ee_Initialize(user = '", ee_user$email, "', drive = TRUE)",
       " to fix."
     )
   }
@@ -561,7 +561,7 @@ ee_init_task_gcs_fc <- function(x_fc, dsn, container, table_id,
     ee_save_credential(pgcs = gcs_credential$path)
     message(
       "\nGoogle Cloud Storage credentials were not loaded.",
-      " Running ee_Initialize(email = '",ee_user$email,"', gcs = TRUE)",
+      " Running ee_Initialize(user = '", ee_user$email, "', gcs = TRUE)",
       " to fix."
     )
   }
